import {
  select,
  csv,
  scaleLinear,
  extent,
  scaleBand,
  axisLeft,
  axisBottom,
  format, line,curveBasis,
  max, scaleTime
} from 'd3';


const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');


const render = data => {
const title = 'A Week in San Francisco';
  
const xValue = d => d.timestamp;
const xAxisLabel = 'Time';
  
const yValue = d => d.temperature;
const circleRadius = 6;
const yAxisLabel = 'Temperature';
  
const margin = { top: 60, right: 40, bottom: 88, left: 105 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;
  
const xScale = scaleTime()
.domain(extent(data, xValue))
.range([0, innerWidth])
.nice();
  
const yScale = scaleLinear()
.domain(extent(data, yValue))
.range([innerHeight, 0])
.nice();

  
  
 console.log(yScale.domain()) 
  
const g = svg.append('g')
.attr('transform', `translate(${margin.left},${margin.top})`);
  
 

const xAxisTickFormat = number =>
format('.3s')(number)
.replace('Mar', 'Sun');
  
const xAxis= axisBottom(xScale)
.tickSize(-innerHeight)
.tickPadding(15);

 
const yAxis= axisLeft(yScale)
.tickSize(-innerWidth)
.tickPadding(10)

const xAxisG= g.append('g').call(xAxis)
.attr('transform',`translate(0,${innerHeight})`)

xAxisG.append('text')
.attr('class','axis-label') 
.attr('y',85)
.attr('x',innerWidth/2)
.text(xAxisLabel)
      

const yAxisG= g.append('g').call(yAxis)  
.append('text')
.attr('class','axis-label')
.attr('x',-(innerHeight/2))
.attr('y',-60)
.attr('transform','rotate(-90)')
.attr('text-anchor','middle')
.text(yAxisLabel)


// now for the plotting
const lineGenerator= line()
.x(d=>xScale(xValue(d)))
.y(d=>yScale(yValue(d)))
.curve(curveBasis) 

g.append('path')
.attr('class','line-path')
.attr('d',lineGenerator(data))  

//now for the title
const myTitle= g.append('g')
.append('text')
.attr('class','title')
.attr('y',-10)
.text(title)

};

csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv')
.then(function(data){
data.forEach(function(d){
d.temperature=+d.temperature;
d.timestamp= new Date(d.timestamp)})
render(data)
console.log(data)
})